@@ -6,8 +6,8 @@
 #' @param user Vector of user names, user IDs, or a mixture of both.
 #' @param n Number of tweets to return per timeline. Defaults to 100.
 #'   Must be of length 1 or equal to length of user.
-#' @param max_id Character, status_id from which returned tweets
-#'   should be older than.
+#' @param max_id Character, returns results with an ID less than (that is,
+#'   older than) or equal to `max_id`.
 #' @param home Logical, indicating whether to return a user-timeline
 #'   or home-timeline. By default, home is set to FALSE, which means
 #'   \code{get_timeline} returns tweets posted by the given user. To
@@ -20,11 +20,12 @@
 #' @param check Logical indicating whether to remove check available
 #'   rate limit. Ensures the request does not exceed the maximum
 #'   remaining number of calls.  Defaults to TRUE.
-#' @param token OAuth token. By default \code{token = NULL} fetches a
-#'   non-exhausted token from an environment variable. Find
-#'   instructions on how to create tokens and setup an environment
-#'   variable in the tokens vignette (in r, send \code{?tokens} to
-#'   console).
+#' @param token Every user should have their own Oauth (Twitter API) token. By
+#'   default \code{token = NULL} this function looks for the path to a saved
+#'   Twitter token via environment variables (which is what `create_token()`
+#'   sets up by default during initial token creation). For instruction on how
+#'   to create a Twitter token see the tokens vignette, i.e.,
+#'   `vignettes("auth", "rtweet")` or see \code{?tokens}.
 #' @param ... Further arguments passed on as parameters in API query.
 #' @return A tbl data frame of tweets data with users data attribute.
 #' @seealso
@@ -66,10 +67,12 @@ get_timeline <- function(user,
   args <- list(
     user = user,
     n = n,
+    home = home,
     max_id = max_id,
     parse = parse,
     check = check,
-    token = token
+    token = token,
+    ...
   )
   do.call("get_timeline_", args)
 }
@@ -90,7 +93,7 @@ get_timelines <- function(user,
 }
 
 
-get_timeline_ <- function(user, n = 100, ...) {
+get_timeline_ <- function(user, n = 100, home = FALSE, ...) {
   ## check inputs
   stopifnot(is.atomic(user), is.numeric(n))
   if (length(user) == 0L) {
@@ -98,19 +101,16 @@ get_timeline_ <- function(user, n = 100, ...) {
   }
   ## search for each string in column of queries
   dots <- list(...)
+
   if (length(dots) > 0L) {
-    rt <- Map(get_timeline_call, user = user, n = n, MoreArgs = dots)
+    rt <- Map(get_timeline_call, user = user, n = n, home = home, MoreArgs = dots)
   } else {
-    rt <- Map(get_timeline_call, user = user, n = n)
+    rt <- Map(get_timeline_call, user = user, n = n, home = home)
   }
-  ## merge users data into one data frame
-  rt_users <- do.call("rbind", lapply(rt, users_data))
   ## merge tweets data into one data frame
   rt <- do.call("rbind", rt)
-  ## set users attribute
-  attr(rt, "users") <- rt_users
   ## return tibble (validate = FALSE makes it a bit faster)
-  tibble::as_tibble(rt, validate = FALSE)
+  as_tbl(rt)
 }
 
 
@@ -137,10 +137,13 @@ get_timeline_call <- function(user,
     stop("can only return tweets for one user at a time.",
       call. = FALSE)
   }
-  token <- check_token(token, query)
+  token <- check_token(token)
   if (check) {
     rl <- rate_limit(token, query)
     n.times <- rl[["remaining"]]
+    if (n %/% 200 < n.times) {
+      n.times <- ceiling(n / 200L)
+    }
   } else {
     rl <- NULL
     n.times <- ceiling(n / 200L)
@@ -174,11 +177,7 @@ get_timeline_call <- function(user,
   tm <- scroller(url, n, n.times, type = "timeline", token)
   if (parse) {
     tm <- tweets_with_users(tm)
-    usr <- users_data(tm)
-    if (nrow(usr) > 0L) {
-      uq <- !duplicated(usr$user_id)
-      attr(tm, "users") <- usr[uq, ]
-    }
   }
   tm
 }
+
